@@ -78,6 +78,10 @@ class Rights(BaseModel):
     free_watch: bool = None
 
 
+class SearchResultKetang(BaseModel):
+    type: SearchType = SearchType.KETANG
+
+
 class SearchResultUser(BaseModel):
     type: SearchType = SearchType.BILI_USER
     mid: int
@@ -178,6 +182,14 @@ class RequestLoginKeyResponse(BaseModel):
     key: str
 
 
+class CookieInfoResponse(BaseResponse):
+    class CookieInfoResponseData(BaseModel):
+        refresh: bool
+        timestamp: int
+
+    data: CookieInfoResponseData = None
+
+
 class SendSmsCodeResponse(BaseResponse):
     class SendSmsCodeResponseData(BaseModel):
         captcha_key: str
@@ -216,6 +228,10 @@ class NavInfoResponse(BaseResponse):
             bcoin_balance: int  # B币
             coupon_balance: int  # 赠送B币数
 
+        class Wbi(BaseModel):
+            img_url: str
+            sub_url: str
+
         isLogin: bool
         email_verified: bool = None
         face: str = None
@@ -231,6 +247,7 @@ class NavInfoResponse(BaseResponse):
         wallet: Wallet = None
         level_info: LevelInfo = None
         vip_label: VipLabel = None
+        wbi_img: Wbi = None
 
         @classmethod
         @validator('vipDueDate')
@@ -254,7 +271,8 @@ class SearchResponse(BaseResponse):
         egg_hit: int
         pageinfo: dict = None
         result: Union[List[Union[SearchResultVideo, SearchResultUser,
-                                 SearchResultLiveRoom, SearchResultMedia]], dict] = None
+                                 SearchResultLiveRoom, SearchResultMedia,
+                                 SearchResultKetang]], dict] = None
         show_column: int
 
     data: SearchResponseData = None
@@ -804,8 +822,8 @@ class VideoHotCommentsResponse(BaseResponse):
 
             class Content(BaseModel):
                 message: str
-                plat: int
-                device: str
+                # plat: int
+                # device: str
 
             rpid: int
             like: int
