@@ -13,7 +13,8 @@ from fuo_bilibili.api.schema.responses import SearchResponse, SearchResultVideo,
     FavoriteSeasonResourceResponse, HistoryLaterVideoResponse, HomeDynamicVideoResponse, UserInfoResponse, \
     UserBestVideoResponse, UserVideoResponse, AudioFavoriteSongsResponse, AudioFavoriteListResponse, AudioPlaylist, \
     AudioPlaylistSong, VideoHotCommentsResponse, SearchResultUser, LiveFeedListResponse, SearchResultLiveRoom, \
-    SearchResultMedia, MediaGetListResponse, VideoWeeklyListResponse
+    SearchResultMedia, MediaGetListResponse, VideoWeeklyListResponse, VideoMostPopularResponse, \
+    HomeRecommendVideosResponse
 from fuo_bilibili.util import format_timedelta_to_hms
 
 PROVIDER_ID = __identifier__
@@ -221,7 +222,7 @@ class BSearchModel:
         return BVideoModel(
             source=PROVIDER_ID,
             identifier=f'live_{live.roomid}',
-            title=live.title,
+            title=get_text_from_html(live.title),
             artists=[
                 BriefArtistModel(
                     source=PROVIDER_ID,
@@ -477,7 +478,7 @@ class BVideoModel(VideoModel):
         return cls(
             source=PROVIDER_ID,
             identifier=f'live_{live.roomid}',
-            title=live.title,
+            title=get_text_from_html(live.title),
             artists=[
                 BriefArtistModel(
                     source=PROVIDER_ID,
@@ -489,6 +490,40 @@ class BVideoModel(VideoModel):
             cover=live.cover,
         )
 
+    @classmethod
+    def create_recommend_video_model(cls, result: HomeRecommendVideosResponse.HomeRecommendVideosResponseData.Video):
+        return VideoModel(
+            source=PROVIDER_ID,
+            identifier=result.bvid,
+            title=get_text_from_html(result.title),
+            artists=[BriefArtistModel(
+                source=PROVIDER_ID,
+                identifier=result.owner.mid,
+                name=result.owner.name
+            )],
+            duration=result.duration.total_seconds(),
+            cover=wrap_pic(result.pic),
+            play_count=result.stat.view,
+        )
+
+
+    @classmethod
+    def create_popular_video_model(cls, result: VideoMostPopularResponse.VideoMostPopularResponseData.PopularVideo):
+        return VideoModel(
+            source=PROVIDER_ID,
+            identifier=result.bvid,
+            title=get_text_from_html(result.title),
+            artists=[BriefArtistModel(
+                source=PROVIDER_ID,
+                identifier=result.owner.mid,
+                name=result.owner.name
+            )],
+            duration=result.duration.total_seconds(),
+            cover=wrap_pic(result.pic),
+            play_count=result.stat.view,
+            released=result.pubdate.strftime('%Y-%m-%d'),
+        )
+
     @classmethod
     def create_video_model(cls, result: SearchResultVideo) -> 'VideoModel':
         return VideoModel(
